<?php

namespace Drupal\wn_events\Plugin\views\area;

use Drupal\comment\CommentInterface;
use Drupal\comment\Entity\Comment;
use Drupal\views\Plugin\views\area\AreaPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Brick\Math\BigDecimal;

/**
 * order statistics area handler.
 *
 * @ingroup views_area_handlers
 *
 * @ViewsArea("wn_events_statistics_area")
 */
class WnEventsStatisticsArea extends AreaPluginBase {

  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * @inheritDoc
   */
  public function render($empty = FALSE) {
    $search_title = \Drupal::request()->query->get('title');
    $aggregate_query = \Drupal::entityQueryAggregate('comment');
    $max_min_query = \Drupal::entityQuery('comment');
    if (!empty($search_title)) {
      $or_condition = $aggregate_query->orConditionGroup();
      $or_max_min_query = $aggregate_query->orConditionGroup();
      $nids = \Drupal::entityQuery('node')
        ->accessCheck(TRUE)
        ->condition('type', 'wn_events')
        ->condition('title', $search_title, 'CONTAINS')
        ->execute();
      if (!empty($nids)) {
        foreach ($nids as $nid) {
          $or_condition->condition('entity_id', $nid);
          $or_max_min_query->condition('entity_id', $nid);
        }
        $aggregate_query->condition($or_condition);
        $max_min_query->condition($or_max_min_query);
      }
    }
    $aggregate_query->accessCheck(TRUE)
      ->aggregate('field_wn_order_number', 'COUNT')
      ->aggregate('field_wn_events_money', 'SUM')
      ->aggregate('field_wn_events_money', 'AVG')
      ->condition('field_wn_events_paid', [
        YK_ORDER_STATE_SUCCESS,
        YK_ORDER_STATE_REFUND_PROGRESS,
        YK_ORDER_STATE_REFUND_PART,
      ], 'IN')
      ->condition('comment_type', 'wn_events_comment')
      ->condition('status', CommentInterface::PUBLISHED);
    $total = $aggregate_query->execute();
    $max_min_query->accessCheck(TRUE)
      ->condition('field_wn_events_paid', [
        YK_ORDER_STATE_SUCCESS,
        YK_ORDER_STATE_REFUND_PROGRESS,
        YK_ORDER_STATE_REFUND_PART,
      ], 'IN')
      ->condition('comment_type', 'wn_events_comment')
      ->condition('status', CommentInterface::PUBLISHED);
    $results = $max_min_query->execute();
    $total[0]['field_wn_events_money_max'] = 0;
    $total[0]['field_wn_events_money_min'] = 0;
    if (!empty($results)) {
      foreach ($results as $cid) {
        $str_money = Comment::load($cid)->get('field_wn_events_money')->value;
        $number_money = BigDecimal::of($str_money)->toFloat();
        if ($total[0]['field_wn_events_money_max'] < $number_money) {
          $total[0]['field_wn_events_money_max'] = $number_money;
        }
        if ($total[0]['field_wn_events_money_min'] == 0 || $total[0]['field_wn_events_money_min'] > $number_money) {
          $total[0]['field_wn_events_money_min'] = $number_money;
        }
      }
    }
    // Except for personnel statistics, all other data should be rounded to two decimal places
    // 除了人数统计，其他数据保留小数点后两位
    if (!empty($total) && array_key_exists(0, $total)) {
      foreach ($total[0] as $key => $item) {
        if ($key == "field_wn_order_number_count") {
          continue;
        }
        if ($item == NULL) {
          $item = 0;
        }
        $total[0][$key] = sprintf("%.2f", $item);
      }
    }
    $data = [
      'total' => $total,
    ];
    $build = [
      '#theme' => 'wn_events_statistics',
      '#data' => $data,
      '#cache' => [
        'max-age' => 0,
      ],
    ];
    return $build;
  }

}
